#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include "tsync.h"
#include "tsync_example.h"


int main (int argc, char *argv[])
{
    TSYNC_BoardHandle  hnd;
    int                rc;
    int                i;
    int                ret     = 0;
    int                devIdx;
    char              *devName = DEFAULT_DEV;
    char               fullDevName[32];
    char              *pgmname = argv[0];
    TSYNC_ERROR        err     = TSYNC_SUCCESS;
    unsigned int       index;
    TSYNC_HsCtlObj     ctl;


    /* If invalid number of arguments... */
    if ((argc != 6))
    {
        printf(" Usage: HS_SetCtl <device index> <fan1 en> <fan 2 en> <fan 1 speed> <fan2 speed>\n");
        return (1);
    }

    /* Construct the TSYNC/TSAT device name */
    devIdx = atoi(argv[1]);
    (void)sprintf( fullDevName, "%s%s%d", DEVICE_ROOT, devName, devIdx );

    /* Build Set Format message */
    ctl.sled1.fan_en  = atoi(argv[2]);
    ctl.sled2.fan_en  = atoi(argv[3]);
    ctl.sled1.fan_pwm = atoi(argv[4]);
    ctl.sled2.fan_pwm = atoi(argv[5]);

    /*
     * open the device
     */
    if ( (rc = TSYNC_open(&hnd, fullDevName)) != TSYNC_SUCCESS )
    {
        /*
         * if errors, close it
         */
        printf("%s: !Could not open <%s> : rc <%d>\n",
                        pgmname, fullDevName, rc);
        return (1);
    }

    printf("\n HS_Ctl:\n");
    printf("  Sled 1 Enable: %d\n", ctl.sled1.fan_en);
    printf("  Sled 1 PWM:    %d\n", ctl.sled1.fan_pwm);
    printf("  Sled 2 Enable: %d\n", ctl.sled2.fan_en);
    printf("  Sled 2 PWM:    %d\n", ctl.sled2.fan_pwm);

    // Send Set Format transaction
    err = TSYNC_HS_setCtl(hnd, &ctl);

    if (err != TSYNC_SUCCESS)
    {
        printf("  Error: %s.\n", tsync_strerror(err));
        return (1);
    }

    /* Close the TSYNC/TSAT device */
    if ( (rc = TSYNC_close(hnd)) != TSYNC_SUCCESS )
    {
        (void) printf("%s: error closing <%s> rc: <%d>\n",
                pgmname, fullDevName, rc );
        ret = 1;
    }

    return (ret);

} /* End - main() */
