#include "tsync.h"

#include <cstdio>
#include <cstdlib>
#include <iostream>
#include <vector>


uint32_t getOptionsAmount(TSYNC_BoardHandle& pHandle)
{
    uint32_t optionsAmount;

    TSYNC_ERROR err = TSYNC_SW_getSwitchOptionsAmount(pHandle, &optionsAmount);

    if (err != TSYNC_SUCCESS)
        throw tsync_strerror(err);

    return optionsAmount;
}

std::string getOptionValue(TSYNC_BoardHandle& pHandle, uint32_t index)
{
    TSYNC_SwitchOptionObj option;

    TSYNC_ERROR err = TSYNC_SW_getSwitchOption(pHandle, &option, index);

    if (err != TSYNC_SUCCESS)
        throw tsync_strerror(err);

    return option.value;
}

std::vector<std::string> getOptions(TSYNC_BoardHandle& pHandle)
{
    auto optionsAmount = getOptionsAmount(pHandle);

    std::vector<std::string> options;
    options.reserve(optionsAmount);

    for (uint32_t i = 0; i < optionsAmount; ++i)
    {
        auto value = getOptionValue(pHandle, i);
        options.push_back(value);
    }

    return options;
}

void print(const std::vector<std::string>& options)
{
    std::cout << "Options: ";

    for (const auto& option : options)
        std::cout << option << " ";

    std::cout << std::endl;
}


int main(int argc, char* argv[])
{
    if (argc != 2)
    {
        fprintf(stderr, " Usage: SW_GetOptions <device>\n");
        return EXIT_FAILURE;
    }

    int devId = atoi(argv[1]);

    char deviceName[32] = {0};
    sprintf(deviceName, "/dev/tsyncpci%d", devId);

    TSYNC_BoardHandle pHandle;

    if (TSYNC_open(&pHandle, deviceName) != TSYNC_SUCCESS)
    {
        fprintf(stderr, "%s: Could not open <%s>\n", argv[0], deviceName);
        return EXIT_FAILURE;
    }

    try
    {
        auto options = getOptions(pHandle);
        print(options);
    }
    catch (const char* error)
    {
        fprintf(stderr, "  Error: %s\n", error);
        return EXIT_FAILURE;
    }

    return EXIT_SUCCESS;
}